==> vue2-leaflet-inikolov-simple-tools-1.0.14.tgz: package/README.md <==
#   L e a f l e t   s i m p l e   t o o l s   f o r   v u e 2 
 
 S i m p l e   v u e 2   p a c k a g e   t o   b e   p o s s i b l e   u s i n g   o f   f e w   p a c k a g e s   i n   v u e   p r o j e c t s . 
 
 # #   P A C K A G E S 
 
 [ L e a f l e t . f u l l s c r e e n ] ( h t t p s : / / g i t h u b . c o m / L e a f l e t / L e a f l e t . f u l l s c r e e n ) 
 
 [ M a p   P r i n t   P l u g i n   f o r   L e a f l e t . j s ] ( h t t p s : / / g i t h u b . c o m / I g o r - V l a d y k a / l e a f l e t . b r o w s e r . p r i n t ) 
 
 
 # #   U s a g e 
 
 Y o u   c a n   r e a d   t h e   d o c u m e n t a t i o n   o f   t h e   p a c k a g e s   a b o v e   a n d   u s e   t h e i r   o p t i o n s   l i k e   i n   t h e   e x a m p l e   b e l o w   ( f u l l s c r e e n O p t i o n s   a n d   p r i n t O p t i o n s ) . 
 
 # # #   I M P O R T A N T   F O R   p r i n t M o d e s 
 
 I   r e p l a c e d   t h e   o r i g i n a l   p r i n t   m o d e s   o p t i o n   f r o m   t h e   d o c u m e n t a t i o n   o f   t h e   p r i n t   p l u g i n .   P l e a s e   s e e   t h e   p r i n t M o d e s   i n   t h e   e x a m p l e   b e l o w . 
 
 ` ` ` h t m l 
 < t e m p l a t e > 
     < d i v   s t y l e = " h e i g h t :   1 0 0 % ;   w i d t h :   1 0 0 % " > 
         < l - m a p 
             s t y l e = " h e i g h t :   4 0 0 p x " 
             : c e n t e r = " m a p C e n t r e " 
             : z o o m = " m a p Z o o m " 
             r e f = " m a p " 
         > 
             < l - t i l e - l a y e r 
                 : u r l = " t i l e U r l " 
                 : a t t r i b u t i o n = " t i l e A t t r i b u t i o n " 
             / > 
             < l - c o n t r o l - f u l l s c r e e n   p o s i t i o n = " t o p l e f t "   : o p t i o n s = " f u l l s c r e e n O p t i o n s "   / > 
             < l - c o n t r o l - p r i n t   : o p t i o n s = " p r i n t O p t i o n s "     / > 
         < / l - m a p > 
     < / d i v > 
 < / t e m p l a t e > 
 
 < s c r i p t > 
 i m p o r t   L   f r o m   ' l e a f l e t ' ; 
 i m p o r t   { 
     L M a p , 
     L T i l e L a y e r 
 }   f r o m   ' v u e 2 - l e a f l e t ' ; 
 i m p o r t   {   L C o n t r o l P r i n t ,   L C o n t r o l F u l l s c r e e n   }   f r o m   ' v u e 2 - l e a f l e t - i n i k o l o v - s i m p l e - t o o l s ' ; 
 
 e x p o r t   d e f a u l t   { 
     c o m p o n e n t s :   { 
         L M a p , 
         L T i l e L a y e r , 
         L C o n t r o l P r i n t , 
         L C o n t r o l F u l l s c r e e n 
     } , 
     d a t a ( )   { 
         r e t u r n   { 
             m a p C e n t r e :   [ 5 1 ,   - 1 1 4 ] , 
             m a p Z o o m :   1 0 , 
             t i l e U r l :   ' h t t p s : / / { s } . t i l e . o p e n s t r e e t m a p . o r g / { z } / { x } / { y } . p n g ' , 
             t i l e A t t r i b u t i o n :   ' & c o p y ;   < a   h r e f = " / / o s m . o r g / c o p y r i g h t " > O p e n S t r e e t M a p < / a >   c o n t r i b u t o r s ' , 
             f u l l s c r e e n O p t i o n s :   { 
                 t i t l e :   { 
                     ' f a l s e ' :   ' S w i t c h   t o   f u l l - s c r e e n   v i e w ' , 
                     ' t r u e ' :   ' E x i t   f u l l - s c r e e n   m o d e ' , 
                 } , 
             } , 
             p r i n t O p t i o n s :   { 
                 t i t l e :   ' J u s t   p r i n t   m e ! ' , 
                 d o c u m e n t T i t l e :   ' M a p   p r i n t e d   u s i n g   l e a f l e t . b r o w s e r . p r i n t   p l u g i n ' , 
                 c l o s e P o p u p s O n P r i n t :   f a l s e , 
                 p r i n t M o d e s :   [ 
                     { " t y p e " :   ' a l l ' ,   " n a m e " :   ' A l l ' } , 
                     { " t y p e " :   ' l a n d s c a p e ' ,   " n a m e " :   ' L a n d s c a p e ' } , 
                     { ' t y p e ' :   ' p o r t r a i t ' ,   ' n a m e ' :   ' P o r t r a i t ' } , 
                     { ' t y p e ' :   ' c u s t o m ' ,   ' n a m e ' :   ' S e l e c t ' } 
                 ] , 
                 m a n u a l M o d e :   f a l s e 
             } 
         } ; 
     } , 
     m e t h o d s :   { 
 
     } 
 } ; 
 < / s c r i p t > 
 
 < s t y l e > 
 @ i m p o r t   ' ~ l e a f l e t / d i s t / l e a f l e t . c s s ' ; 
 < / s t y l e > 
 
 ` ` ` 

==> vue2-leaflet-inikolov-simple-tools-1.1.0.tgz: package/README.md <==
#   L e a f l e t   s i m p l e   t o o l s   f o r   v u e 2 
 
 S i m p l e   v u e 2   p a c k a g e   t o   b e   p o s s i b l e   u s i n g   o f   f e w   p a c k a g e s   i n   v u e   p r o j e c t s . 
 
 # #   P A C K A G E S 
 
 [ L e a f l e t . f u l l s c r e e n ] ( h t t p s : / / g i t h u b . c o m / L e a f l e t / L e a f l e t . f u l l s c r e e n ) 
 
 [ M a p   P r i n t   P l u g i n   f o r   L e a f l e t . j s ] ( h t t p s : / / g i t h u b . c o m / I g o r - V l a d y k a / l e a f l e t . b r o w s e r . p r i n t ) 
 
 
 [ L e a f l e t . P o l y l i n e M e a s u r e ] ( h t t p s : / / g i t h u b . c o m / p p e t e 2 / L e a f l e t . P o l y l i n e M e a s u r e ) 
 
 
 # #   U s a g e 
 
 Y o u   c a n   r e a d   t h e   d o c u m e n t a t i o n   o f   t h e   p a c k a g e s   a b o v e   a n d   u s e   t h e i r   o p t i o n s   l i k e   i n   t h e   e x a m p l e   b e l o w   ( f u l l s c r e e n O p t i o n s   a n d   p r i n t O p t i o n s ) . 
 
 # # #   I M P O R T A N T   F O R   p r i n t M o d e s 
 
 I   r e p l a c e d   t h e   o r i g i n a l   p r i n t   m o d e s   o p t i o n   f r o m   t h e   d o c u m e n t a t i o n   o f   t h e   p r i n t   p l u g i n .   P l e a s e   s e e   t h e   p r i n t M o d e s   i n   t h e   e x a m p l e   b e l o w . 
 
 ` ` ` h t m l 
 < t e m p l a t e > 
     < d i v   s t y l e = " h e i g h t :   1 0 0 % ;   w i d t h :   1 0 0 % " > 
         < l - m a p 
             s t y l e = " h e i g h t :   4 0 0 p x " 
             : c e n t e r = " m a p C e n t r e " 
             : z o o m = " m a p Z o o m " 
             r e f = " m a p " 
         > 
             < l - t i l e - l a y e r 
                 : u r l = " t i l e U r l " 
                 : a t t r i b u t i o n = " t i l e A t t r i b u t i o n " 
             / > 
             < l - c o n t r o l - f u l l s c r e e n   p o s i t i o n = " t o p l e f t "   : o p t i o n s = " f u l l s c r e e n O p t i o n s "   / > 
             < l - c o n t r o l - p r i n t   : o p t i o n s = " p r i n t O p t i o n s "     / > 
             < l - c o n t r o l - p o l y - l i n e - m e a s u r e   : o p t i o n s = " p o l y l i n e O p t i o n s "   / > 
         < / l - m a p > 
     < / d i v > 
 < / t e m p l a t e > 
 
 < s c r i p t > 
 i m p o r t   { 
     L M a p , 
     L T i l e L a y e r 
 }   f r o m   ' v u e 2 - l e a f l e t ' ; 
 i m p o r t   {   L C o n t r o l P r i n t ,   L C o n t r o l F u l l s c r e e n ,   L C o n t r o l P o l y L i n e M e a s u r e   }   f r o m   ' v u e 2 - l e a f l e t - i n i k o l o v - s i m p l e - t o o l s ' ; 
 
 e x p o r t   d e f a u l t   { 
     c o m p o n e n t s :   { 
         L M a p , 
         L T i l e L a y e r , 
         L C o n t r o l P r i n t , 
         L C o n t r o l F u l l s c r e e n , 
         L C o n t r o l P o l y L i n e M e a s u r e 
     } , 
     d a t a ( )   { 
         r e t u r n   { 
             m a p C e n t r e :   [ 5 1 ,   - 1 1 4 ] , 
             m a p Z o o m :   1 0 , 
             t i l e U r l :   ' h t t p s : / / { s } . t i l e . o p e n s t r e e t m a p . o r g / { z } / { x } / { y } . p n g ' , 
             t i l e A t t r i b u t i o n :   ' & c o p y ;   < a   h r e f = " / / o s m . o r g / c o p y r i g h t " > O p e n S t r e e t M a p < / a >   c o n t r i b u t o r s ' , 
             f u l l s c r e e n O p t i o n s :   { 
                 t i t l e :   { 
                     ' f a l s e ' :   ' S w i t c h   t o   f u l l - s c r e e n   v i e w ' , 
                     ' t r u e ' :   ' E x i t   f u l l - s c r e e n   m o d e ' , 
                 } , 
             } , 
             p r i n t O p t i o n s :   { 
                 t i t l e :   ' J u s t   p r i n t   m e ! ' , 
                 d o c u m e n t T i t l e :   ' M a p   p r i n t e d   u s i n g   l e a f l e t . b r o w s e r . p r i n t   p l u g i n ' , 
                 c l o s e P o p u p s O n P r i n t :   f a l s e , 
                 p r i n t M o d e s :   [ 
                     { " t y p e " :   ' a l l ' ,   " n a m e " :   ' A l l ' } , 
                     { " t y p e " :   ' l a n d s c a p e ' ,   " n a m e " :   ' L a n d s c a p e ' } , 
                     { ' t y p e ' :   ' p o r t r a i t ' ,   ' n a m e ' :   ' P o r t r a i t ' } , 
                     { ' t y p e ' :   ' c u s t o m ' ,   ' n a m e ' :   ' S e l e c t ' } 
                 ] , 
                 m a n u a l M o d e :   f a l s e 
             } , 
             p o l y l i n e O p t i o n s :   { 
                 p o s i t i o n :   ' t o p l e f t ' , 
                 s h o w C l e a r C o n t r o l :   t r u e , 
                 s h o w U n i t C o n t r o l :   t r u e 
             } 
         } ; 
     } , 
     m e t h o d s :   { 
 
     } 
 } ; 
 < / s c r i p t > 
 
 < s t y l e > 
 @ i m p o r t   ' ~ l e a f l e t / d i s t / l e a f l e t . c s s ' ; 
 < / s t y l e > 
 
 ` ` ` 
